@@ -22,9 +22,7 @@
 
 #include "cliplugin.h"
 #include "ark_debug.h"
-#include "kerfuffle/archiveentry.h"
-#include "kerfuffle/cliinterface.h"
-#include "kerfuffle/kerfuffle_export.h"
+#include "cliinterface.h"
 
 #include <KLocalizedString>
 #include <KPluginFactory>
@@ -32,6 +30,7 @@
 #include <QDateTime>
 #include <QDir>
 #include <QRegularExpression>
+#include <QTemporaryDir>
 
 using namespace Kerfuffle;
 
@@ -97,8 +96,8 @@ void CliPlugin::setupCliProperties()
 
     m_cliProps->setProperty("listProgram", QStringLiteral("zipinfo"));
     m_cliProps->setProperty("listSwitch", QStringList{QStringLiteral("-l"),
-                                                  QStringLiteral("-T"),
-                                                  QStringLiteral("-z")});
+                                                      QStringLiteral("-T"),
+                                                      QStringLiteral("-z")});
 
     m_cliProps->setProperty("testProgram", QStringLiteral("unzip"));
     m_cliProps->setProperty("testSwitch", QStringLiteral("-t"));
@@ -107,7 +106,7 @@ void CliPlugin::setupCliProperties()
 
     m_cliProps->setProperty("compressionLevelSwitch", QStringLiteral("-$CompressionLevel"));
     m_cliProps->setProperty("compressionMethodSwitch", QHash<QString,QVariant>{{QStringLiteral("application/zip"), QStringLiteral("-Z$CompressionMethod")},
-                                                                           {QStringLiteral("application/x-java-archive"), QStringLiteral("-Z$CompressionMethod")}});
+                                                                               {QStringLiteral("application/x-java-archive"), QStringLiteral("-Z$CompressionMethod")}});
     m_cliProps->setProperty("multiVolumeSwitch", QStringLiteral("-v$VolumeSizek"));
 
     m_cliProps->setProperty("passwordPromptPatterns", QStringList{QStringLiteral(" password: ")});
@@ -116,13 +115,14 @@ void CliPlugin::setupCliProperties()
     m_cliProps->setProperty("fileExistsPatterns", QStringList{QStringLiteral("^replace (.+)\\? \\[y\\]es, \\[n\\]o, \\[A\\]ll, \\[N\\]one, \\[r\\]ename: $")});
     m_cliProps->setProperty("fileExistsFileName", QStringList{QStringLiteral("^replace (.+)\\? \\[y\\]es, \\[n\\]o, \\[A\\]ll, \\[N\\]one, \\[r\\]ename: $")});
     m_cliProps->setProperty("fileExistsInput", QStringList{QStringLiteral("y"),   //Overwrite
-                                                       QStringLiteral("n"),   //Skip
-                                                       QStringLiteral("A"),   //Overwrite all
-                                                       QStringLiteral("N")}); //Autoskip
+                                                           QStringLiteral("n"),   //Skip
+                                                           QStringLiteral("A"),   //Overwrite all
+                                                           QStringLiteral("N")}); //Autoskip
     m_cliProps->setProperty("extractionFailedPatterns", QStringList{QStringLiteral("unsupported compression method")});
-    m_cliProps->setProperty("corruptArchivePatterns", QStringList{QStringLiteral("End-of-central-directory signature not found")});
+    m_cliProps->setProperty("corruptArchivePatterns", QStringList{QStringLiteral("End-of-central-directory signature not found"),
+                                                                  QStringLiteral("didn't find end-of-central-dir signature at end of central dir")});
     m_cliProps->setProperty("diskFullPatterns", QStringList{QStringLiteral("write error \\(disk full\\?\\)"),
-                                                        QStringLiteral("No space left on device")});
+                                                            QStringLiteral("No space left on device")});
 }
 
 bool CliPlugin::readListLine(const QString &line)
@@ -273,7 +273,7 @@ bool CliPlugin::setMovingAddedFiles()
     if (!QFile::rename(oldPath, newPath)) {
         return false;
     }
-    m_tempAddedFiles << new Archive::Entry(Q_NULLPTR, m_passedDestination->name());
+    m_tempAddedFiles << new Archive::Entry(nullptr, m_passedDestination->name());
 
     // We have to exclude file name from destination path in order to pass it to addFiles method.
     const QString destinationPath = m_passedDestination->fullPath();
@@ -291,7 +291,7 @@ bool CliPlugin::setMovingAddedFiles()
     } else {
         // ...unless the destination path is already a single folder, e.g. "dir/", or a file, e.g. "foo.txt".
         // In this case we're going to add to the root, so we just need to set a null destination.
-        m_passedDestination = Q_NULLPTR;
+        m_passedDestination = nullptr;
     }
 
     return true;
